"""A Google Map type"""

__author__  = 'takanori <takanori@takanory.net>'
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo

try:
  from Products.LinguaPlone.public import *
except ImportError:
  # No multilingual support
  from Products.Archetypes.public import *

from Products.ATContentTypes.content.base import ATCTFolder
from Products.ATContentTypes.content.schemata import finalizeATCTSchema

from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder

from Products.validation.validators.RangeValidator import RangeValidator
from Products.validation.config import validation
from Products.validation import V_REQUIRED

validation.register(RangeValidator('checkLatitude',
                                   minval=-90.0, maxval=90.0))
validation.register(RangeValidator('checkLongitude',
                                   minval=-180.0, maxval=180.0))

from Products.ATGoogleMaps.config import *

zoom_vocaburary = range(18)
zoom_vocaburary.reverse()

GMapSchema = ATCTFolder.schema.copy() + Schema((
    StringField('server',
        default='maps.google.co.jp',
        vocabulary=('maps.google.co.jp', 'maps.google.com', 'maps.google.co.uk'),
        widget=SelectionWidget(
            label='Server',
            label_msgid='label_server',
            description_msgid='help_server',
            i18n_domain='googlemaps',
        )
    ),

    IntegerField('height',
        default="480",
        required=True,
        widget=IntegerWidget(
            label='Height',
            label_msgid='label_height',
            description_msgid='help_height',
            i18n_domain='googlemaps',
        )
    ),
    
    FloatField('latitude',
        required=True,
        validators=(('checkLatitude', V_REQUIRED),),
        widget=DecimalWidget(
            label='Center latitude',
            label_msgid='label_center_latitude',
            description_msgid='help_center_latitude',
            i18n_domain='googlemaps',
            size=12,
        )
    ),
    
    FloatField('longitude',
        required=True,
        validators=(('checkLongitude', V_REQUIRED),),
        widget=DecimalWidget(
            label='Center longitude',
            label_msgid='label_center_longitude',
            description_msgid='help_center_longitude',
            i18n_domain='googlemaps',
            size=12,
        )
    ),
    
    IntegerField('zoom',
        default=3,
        vocabulary=zoom_vocaburary,
        widget=SelectionWidget(
            label='Zoom',
            label_msgid='label_zoom',
            description_msgid='help_zoom',
            i18n_domain='googlemaps',
        )
    ),
    
    StringField('mapControl',
        vocabulary=('large', 'small', 'nothing'),
        default='large',
        widget=SelectionWidget(
            label='Map Control',
            label_msgid='label_map_control',
            description_msgid='help_map_control',
            i18n_domain='googlemaps',
        )
    ),
    
    StringField('mapType',
        vocabulary=('map', 'satellite'),
        default='map',
        widget=SelectionWidget(
            label='Map Type',
            label_msgid='label_map_type',
            description_msgid='help_map_type',
            i18n_domain='googlemaps',
        )
    ),
    
    BooleanField('typeControl',
        default=1,
        widget=BooleanWidget(
            label='Type Control',
            label_msgid='label_type_control',
            description_msgid='help_type_control',
            i18n_domain='googlemaps',
        )
    ),

    BooleanField('overviewControl',
        default=1,
        widget=BooleanWidget(
            label='Overview Control',
            label_msgid='label_overview_control',
            description_msgid='help_overview_control',
            i18n_domain='googlemaps',
        )
    ),
),
)

#Finalize schema definition
finalizeATCTSchema(GMapSchema)

class GMap(ATCTFolder):
    """Google Maps"""
    
    schema          = GMapSchema

    content_icon    = 'gmap_icon.gif'
    portal_type     = 'GMap'
    meta_type       = 'GMap'
    archetype_name  = 'GMap'
    default_view    = 'gmap_view'
    immediate_view  = 'gmap_view'
    suppl_views     = ()
    typeDescription = 'Google maps document'
    typeDescMsgId   = 'gmap_description_edit'

    # Allow images and files to be uploaded into this containerish object
    allowed_content_types = ['GMarker']
    
    # Get the standard actions (tabs)
    #actions = ATCTContent.actions

    #__implements__ = (ATCTFolder.__implements__, INonStructuralFolder)

    # Make sure we get title-to-id generation when an object is created
    _at_rename_after_creation = True

    def canSetDefaultPage(self):
        return False

registerType(GMap, PROJECTNAME)

